import { Button } from 'antd';
import { SHAPE_TYPE, SIZE_TYPE } from 'enums/common';
import { ReactNode, MouseEvent } from 'react';
import styles from './index.module.less';

export interface IButtonProps {
  title: string | any;
  type?: 'filled' | 'outline';
  btnType?:
    | 'link'
    | 'text'
    | 'ghost'
    | 'primary'
    | 'default'
    | 'dashed'
    | undefined;
  disabled?: boolean;
  block?: boolean;
  danger?: boolean;
  ghost?: boolean;
  href?: string;
  htmlType?: 'button' | 'submit' | 'reset' | undefined;
  icon?: ReactNode;
  loading?: boolean | { delay: number };
  shape?: SHAPE_TYPE;
  size?: SIZE_TYPE;
  onClick?: (event: MouseEvent<HTMLButtonElement>) => void;
  className?: string;
}

const BasicButton = (props: IButtonProps) => {
  return (
    <Button
      className={`${props.type && styles[`btn--${props.type}`]} ${
        props.className
      }`}
      type={props.btnType || 'primary'}
      disabled={props.disabled}
      block={props.block}
      danger={props.danger}
      ghost={props.ghost}
      href={props.href}
      icon={props.icon}
      loading={props.loading}
      shape={props.shape}
      size={props.size || 'middle'}
      onClick={props.onClick}
      htmlType={props.htmlType}
    >
      {props.title}
    </Button>
  );
};

export default BasicButton;
