import { SearchOutlined } from '@ant-design/icons';
import { Col, Form, Row } from 'antd';
import BasicInput from 'components/BasicInput';
import SvgIcon from 'components/SvgIcon';
import { paginationConfigDefault100 } from 'constants/common';
import { EFieldType, IFilterItem } from 'hooks/api/useFetchList/useFetchList';
import { useGetHeader } from 'hooks/api/useHeader/useHeader';
import useDebounce from 'hooks/useDebounce';
import { ReactNode, useState } from 'react';
import { useSearchParams } from 'react-router-dom';
import { useFetchList } from 'services/base';
import { removeEmptyValueInObject } from 'utils/common';
import styles from './index.module.less';

interface IUseFilterCustom {
  arrayFilter: IFilterItem[];
  url: string;

  sitemapCode: string;
  headerCode: string;

  titleSearch: string | ReactNode;
}

const useFilterCustom = ({
  arrayFilter,
  url,
  sitemapCode,
  headerCode,
  titleSearch,
}: IUseFilterCustom) => {
  const [searchParams] = useSearchParams();
  const [form] = Form.useForm();
  const defaultFilter: any = (() => {
    const params: any = {
      page: searchParams.get('page')
        ? Number(searchParams.get('page'))
        : paginationConfigDefault100.current,
      limit: searchParams.get('limit')
        ? Number(searchParams.get('limit'))
        : paginationConfigDefault100.pageSize,
      dir: searchParams.get('dir') ?? undefined,
      sort: searchParams.get('sort') ?? undefined,
    };

    arrayFilter.forEach((item: IFilterItem) => {
      params[item.field] = searchParams.get(item.field) || '';
    });

    return params;
  })();
  const [stateQuery, setStateQuery] = useState<any>(
    removeEmptyValueInObject(defaultFilter),
  );
  const searchDebounce = useDebounce();
  const { data: dataHeader, isLoading: isLoadingDataHeader } = useGetHeader({
    sitemapCode: sitemapCode,
    headercode: headerCode,
  });

  const {
    data: dataList,
    isLoading: isLoadingDataList,
    refetch: refetchList,
  } = useFetchList({
    payload: stateQuery,
    url: url,
    filters: arrayFilter,
  });

  const filter = () => {
    const input = arrayFilter.map((item: IFilterItem, index: number) => {
      switch (item.fieldType) {
        case EFieldType.text:
        default:
          return (
            <Col key={index + item.field} span={6}>
              <BasicInput
                placeholder={item.field}
                suffix={<SearchOutlined />}
                allowClear
                name={item.field}
              />
            </Col>
          );
      }
    });

    return (
      <>
        <Form
          form={form}
          className={styles.form}
          onValuesChange={(_changedValue, values) => {
            searchDebounce(() => setStateQuery({ ...stateQuery, ...values }));
          }}
        >
          <div className={styles.title}>{titleSearch}</div>
          <Row gutter={[8, 8]} align="middle">
            {input}
            <Col span={3}>
              <span onClick={() => refetchList()}>
                <SvgIcon icon="refresh-square-2" size={32} color="#3c6d73" />
              </span>
            </Col>
          </Row>
        </Form>
      </>
    );
  };

  return {
    setStateQuery,
    stateQuery,

    dataList: dataList?.data,
    isLoadingDataList,
    refetchList,

    dataHeader,
    isLoadingDataHeader,

    filter: filter(),
  };
};

export { useFilterCustom };
