import { MinusCircleOutlined, PlusOutlined } from '@ant-design/icons';
import { Form, Row, Space } from 'antd';
import BasicButton from 'components/BasicButton';
import BasicInput from 'components/BasicInput';
import BasicSelect from 'components/BasicSelect';
import CommonModal from 'components/CommonModal';
import { SIZE_TYPE } from 'enums/common';
import {
  EFieldType,
  FilterLogic,
  FilterOperator,
  MOCK_DATA,
} from 'hooks/api/useFetchList/useFetchList';
import { useEffect } from 'react';
import { validateMessages } from 'utils/common';
import styles from './index.module.less';

const MOCK_FIELD_LOGIC = [
  {
    label: FilterLogic.AND,
    value: FilterLogic.AND,
  },
  {
    label: FilterLogic.OR,
    value: FilterLogic.OR,
  },
];

const MOCK_FIELD_TYPE = [
  {
    label: EFieldType.text,
    value: EFieldType.text,
  },
];

const MOCK_OPERATOR = [
  {
    label: FilterOperator.CONTAINS,
    value: FilterOperator.CONTAINS,
  },
];

interface IModalFieldSearch {
  visible: boolean;
  setVisible: any;
  data: any[];
  setArrayField: any;
}
const ModalFieldSearch = ({
  visible,
  setVisible,
  setArrayField,
  data,
}: IModalFieldSearch) => {
  const [form] = Form.useForm();

  useEffect(() => {
    form.setFieldsValue({
      filter: data,
    });
  }, []);

  const onFinish = (values: any) => {
    setArrayField(values?.filter);
    setVisible(false);
  };
  return (
    <CommonModal
      title="Update field filter"
      visible={visible}
      onCancel={() => setVisible(false)}
      onOk={() => form.submit()}
      className={styles.modal}
    >
      <Form
        name="dynamic_form_nest_item"
        onFinish={onFinish}
        autoComplete="off"
        form={form}
        validateMessages={validateMessages()}
      >
        <Form.List name="filter">
          {(fields, { add, remove }) => (
            <>
              {fields.map(({ key, name }) => {
                return (
                  <Space
                    key={key}
                    style={{ display: 'flex', marginBottom: 8 }}
                    align="baseline"
                    className={styles.row}
                  >
                    <BasicInput
                      placeholder={'field'}
                      allowClear
                      name={[name, 'field']}
                      rules={[{ required: true }]}
                      label="Field"
                    />

                    <BasicSelect
                      options={MOCK_OPERATOR}
                      name={[name, 'operator']}
                      size={SIZE_TYPE.LARGE}
                      rules={[{ required: true }]}
                      className={styles.fieldSelect}
                    />

                    <BasicSelect
                      options={MOCK_FIELD_LOGIC}
                      name={[name, 'logic']}
                      size={SIZE_TYPE.LARGE}
                      rules={[{ required: true }]}
                      className={styles.fieldSelect}
                    />

                    <BasicSelect
                      options={MOCK_FIELD_TYPE}
                      name={[name, 'fieldType']}
                      size={SIZE_TYPE.LARGE}
                      rules={[{ required: true }]}
                      className={styles.fieldSelect}
                    />

                    <MinusCircleOutlined onClick={() => remove(name)} />
                  </Space>
                );
              })}

              <Form.Item>
                <BasicButton
                  title={<PlusOutlined />}
                  btnType="dashed"
                  onClick={() => add()}
                  className={styles['btn--add']}
                />
              </Form.Item>
            </>
          )}
        </Form.List>
      </Form>
    </CommonModal>
  );
};

export default ModalFieldSearch;
