import { PlusCircleOutlined } from '@ant-design/icons';
import { Col, Row } from 'antd';
import CommonTable from 'components/CommonTable';
import { headerCode, sitemapCode } from 'constants/common';
import { MOCK_DATA } from 'hooks/api/useFetchList/useFetchList';
import { useFilterCustom } from 'hooks/useFilterCustom';
import { HeaderTableFields } from 'models/common';
import { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import ModalFieldSearch from '../component/modalFieldSearch';
import styles from './index.module.less';
import { ItemList } from './interface';

const UserList = () => {
  const navigate = useNavigate();
  const [arrayField, setArrayField] = useState(MOCK_DATA);
  const [columnsTable, setColumnsTable] = useState<HeaderTableFields[]>([]);
  const [visible, setVisible] = useState(false);
  const titleSearch = (
    <Row gutter={5} align="middle">
      <Col>Search</Col>
      <Col onClick={() => setVisible(true)} className={styles.cursor}>
        <PlusCircleOutlined />
      </Col>
    </Row>
  );

  const {
    setStateQuery,
    stateQuery,

    dataList,
    isLoadingDataList,

    dataHeader,
    isLoadingDataHeader,

    filter,
  } = useFilterCustom({
    url: 'users/paging',
    arrayFilter: arrayField,
    sitemapCode: sitemapCode.notification,
    headerCode: headerCode.notificationSetting,
    titleSearch: titleSearch,
  });

  useEffect(() => {
    if (dataHeader && dataHeader.data) {
      let data = dataHeader?.data?.items[0].columns || [];
      if (data.length) {
        setColumnsTable([...data]);
      }
    }
  }, [dataHeader, stateQuery]);

  return (
    <div>
      <CommonTable
        rowKey={(record: ItemList) => record.id}
        data={dataList?.data}
        columns={columnsTable}
        pagination={{
          current: dataList?.meta?.pagination?.page,
          pageSize: dataList?.meta?.pagination?.limit,
          total: dataList?.meta?.pagination?.totalRecords,
        }}
        stateQuery={stateQuery}
        setStateQuery={setStateQuery}
        loading={isLoadingDataHeader || isLoadingDataList}
        extra={filter}
        className={styles.table}
        // onRow={(record: ItemList) => ({
        //   onClick: () => navigate(`/user/detail/${record.id}`),
        // })}
      />

      <ModalFieldSearch
        visible={visible}
        setVisible={setVisible}
        data={arrayField}
        setArrayField={(data: any) => setArrayField(data)}
      />
    </div>
  );
};

export default UserList;
