import { IFilterItem } from 'hooks/api/useFetchList/useFetchList';
import { useQuery } from 'react-query';
import { axiosClient } from './axiosClient';

interface IFetchList {
  payload: any;
  url: string;
  filters: IFilterItem[];
}

interface IQuery {
  sort?: string;
  dir?: string;
  [index: string]: any;
}

const handleFilter = (filter: IFilterItem[], stateQuery: IQuery) => {
  return {
    pagination: {
      skip: (stateQuery.page - 1) * stateQuery.limit,
      limit: stateQuery.limit,
    },
    filter: filter.map((item) => {
      return {
        field: item.field,
        value: stateQuery[item.field] || '',
        operator: item.operator,
        logic: item.logic,
      };
    }),
    sorts: [
      {
        field: stateQuery.dir,
        order: stateQuery.sort === 'ascend' ? 'asc' : 'desc',
      },
    ],
  };
};

export const useFetchList: any = ({ payload, url, filters }: IFetchList) => {
  const newPayload = JSON.stringify(handleFilter(filters, payload));

  return useQuery([url, newPayload, payload], () =>
    axiosClient.get(url, {
      baseURL: process.env.REACT_APP_API_URL,
      params: {
        filter: newPayload,
      },
    }),
  );
};
