import { DATE_DISPLAY, SortDir } from 'constants/common';
import { STATUS_ACTIVE } from 'enums/common';
import { Pagination, QueryParams } from 'models/common';
import moment from 'moment-timezone';
import i18n from 'i18n';

const { t } = i18n;

export const convertToDateTimeUtc = (
  date: string | moment.Moment,
  currentFormat = DATE_DISPLAY,
) => {
  return moment(date, currentFormat).utc().format();
};
export const isEmptyPagination = (pagination: Pagination) => {
  return Object.entries(pagination).length === 0;
};

export const optsStatusActive = () => [
  {
    label: t('status.active'),
    value: STATUS_ACTIVE.ACTIVE,
  },
  {
    label: t('status.inactive'),
    value: STATUS_ACTIVE.INACTIVE,
  },
];
export const removeEmptyValueInObject = (obj: any) => {
  for (const propName in obj) {
    if (obj[propName] === null || obj[propName] === undefined) {
      delete obj[propName];
    }
  }
  return obj;
};

export const sortInforWithDir = (
  field: string | undefined,
  stateQuery: QueryParams<string>,
) => {
  if (field != null) {
    return (
      stateQuery?.sort === field &&
      (stateQuery?.dir === SortDir.ASC ? 'ascend' : 'descend')
    );
  }
};
export const isHTMLTag = (text: string) => {
  return /<\/?[a-z][\s\S]*>/i.test(text);
};

export const validateMessages = () => ({
  required: '${label}' + ` ${t('isRequired')}`,
  types: {
    email: '${label}' + ` ${t('isNotAValidEmail')}`,
    number: '${label}' + ` ${t('isNotAValidNumber')}`,
  },
  number: {
    range:
      '${label}' +
      ` ${t('mustBeBetween')} ` +
      '${min}' +
      ` ${t('and')} ` +
      '${max}',
  },
});
